@@ -2,7 +2,7 @@ package enum::prefix;
 use warnings;
 use strict;
 use 5.006;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my $ident = '[^\W_0-9]\w*';
 
@@ -25,11 +25,10 @@ sub import
 		{
 			my $n = $index;
 			$index++;
-			*{ $pkg . $prefix . '_' . $name } = sub { $n };
+			*{ $pkg . $prefix . $name } = sub(){ $n };
 			$enum[$n] = $name;
 		}
 	}
-
 	*{$pkg. $prefix . $name_sub_suffix } = sub($) { $enum[ $_[0] ] };
 }
 
